Skip to content

Ad Campaign Group Video Groups

Updated: May 18, 2019

Reading

This endpoint fetches video groups used in a campaign group.

Example

Select language

HTTPPHP SDKJavaScript SDKAndroid SDKiOS SDK


GET /v25.0/{campaign-id}/video_groups HTTP/1.1  
Host: graph.facebook.com

Try it in Graph API Explorer

If you want to learn how to use the Graph API, read our Using Graph API guide

Parameters

ParameterDescription
date_range JSON objectThis field contains the date range for which we want to display the video assets. --- start datetime/timestamp Default value: 0 start end datetime/timestamp Default value: <request_time> end Show child parameters

Fields

Reading from this edge will return a JSON formatted result:

{
"data": [],
"paging": {}
}
data

A list of VideoGroup nodes.

paging

For more details about pagination, see the Graph API guide.

Error Codes

Error CodeDescription
100Invalid parameter

Creating

You can't perform this operation on this endpoint.

Updating

You can't perform this operation on this endpoint.

Deleting

You can't perform this operation on this endpoint.

Unofficial mirror for reference/search purposes. All content originates from developers.facebook.com — see the source link at the top of each page. Machine-readable indexes: llms.txt · llms-full.txt · About