Skip to content

Business Whatsapp Business Accounts

Updated: May 12, 2022

Reading

Parameters

This endpoint doesn't have any parameters.

Fields

Reading from this edge will return a JSON formatted result:

{
"data": [],
"paging": {}
}
data

A list of WhatsAppBusinessAccount nodes.

paging

For more details about pagination, see the Graph API guide.

Error Codes

Error CodeDescription
200Permissions error
100Invalid parameter

Creating

You can't perform this operation on this endpoint.

Updating

You can't perform this operation on this endpoint.

Deleting

You can't perform this operation on this endpoint.

Unofficial mirror for reference/search purposes. All content originates from developers.facebook.com — see the source link at the top of each page. Machine-readable indexes: llms.txt · llms-full.txt · About