Skip to content

Product Catalog Smart Pixel Settings

Updated: Apr 8, 2021

Reading

self explanatory

Example

Select language

HTTPPHP SDKJavaScript SDKAndroid SDKiOS SDK


GET /v25.0/{product-catalog-id}/smart_pixel_settings HTTP/1.1  
Host: graph.facebook.com

Try it in Graph API Explorer

If you want to learn how to use the Graph API, read our Using Graph API guide

Parameters

This endpoint doesn't have any parameters.

Fields

Reading from this edge will return a JSON formatted result:

{
"data": [],
"paging": {}
}
data

A list of CatalogSmartPixelSettings nodes.

paging

For more details about pagination, see the Graph API guide.

Error Codes

Error CodeDescription
100Invalid parameter

Creating

You can't perform this operation on this endpoint.

Updating

You can't perform this operation on this endpoint.

Deleting

You can't perform this operation on this endpoint.

Unofficial mirror for reference/search purposes. All content originates from developers.facebook.com — see the source link at the top of each page. Machine-readable indexes: llms.txt · llms-full.txt · About